@@ -2,12 +2,13 @@
 {
   ##set start-up message:
   txt <- c("\n",
-    paste(sQuote("gets"), "version 0.25\n"),
+    paste(sQuote("gets"), "version 0.26\n"),
     "\n",
-    paste0("General-to-Specific (GETS) and Indicator Saturation (ISAT) methods, type help(", sQuote("gets-package"), ") for details"),
+    paste0("General-to-Specific (GETS) and Indicator Saturation (ISAT) methods,",
+    " type help(", dQuote("gets-package", q=FALSE), ") for details"),
     "\n",
     paste("CRAN website: https://CRAN.R-project.org/package=gets"),
-    paste("An introduction (PDF): https://www.jstatsoft.org/article/view/v086i03"),
+    paste0("Type browseVignettes(", dQuote("gets", q=FALSE), ") for an introduction"),
     "\n",
     paste("For automatic plotting, set plot=TRUE in options: options(plot = TRUE)"),
     "\n")
